==> cloud-3.0.0-rc1.tar.gz: cloud/src/Entity/CloudStore.php <==
<?php

namespace Drupal\cloud\Entity;

use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\RevisionableContentEntityBase;
use Drupal\Core\Entity\RevisionableInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\user\EntityOwnerInterface;
use Drupal\user\UserInterface;

/**
 * Defines the cloud Store entity.
 *
 * @ingroup cloud_store
 *
 * @ContentEntityType(
 *   id = "cloud_store",
 *   id_plural = "cloud_stores",
 *   label = @Translation("Cloud Store"),
 *   label_collection = @Translation("Cloud Stores"),
 *   label_singular = @Translation("cloud store"),
 *   label_plural = @Translation("cloud stores"),
 *   bundle_label = @Translation("cloud store type"),
 *   handlers = {
 *     "storage"      = "Drupal\cloud\Entity\CloudStoreStorage",
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudStoreListBuilder",
 *     "views_data"   = "Drupal\cloud\Entity\CloudStoreViewsData",
 *     "translation"  = "Drupal\cloud\Entity\CloudStoreTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\cloud\Form\CloudStoreForm",
 *       "add"     = "Drupal\cloud\Form\CloudStoreForm",
 *       "edit"    = "Drupal\cloud\Form\CloudStoreForm",
 *       "delete"  = "Drupal\cloud\Form\CloudStoreDeleteForm",
 *       "copy"    = "Drupal\cloud\Form\CloudStoreForm",
 *       "delete-multiple-confirm" = "Drupal\cloud\Form\CloudStoreDeleteMultipleForm",
 *     },
 *     "access" = "Drupal\cloud\Controller\CloudStoreAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\cloud\Routing\CloudStoreHtmlRouteProvider",
 *     },
 *   },
 *   base_table          = "cloud_store",
 *   data_table          = "cloud_store_field_data",
 *   revision_table      = "cloud_store_revision",
 *   revision_data_table = "cloud_store_field_revision",
 *   translatable        = TRUE,
 *   admin_permission    = "administer cloud stores",
 *   entity_keys = {
 *     "id" = "id",
 *     "revision" = "vid",
 *     "bundle"   = "type",
 *     "label"    = "name",
 *     "uuid"     = "uuid",
 *     "uid"      = "uid",
 *     "langcode" = "langcode",
 *     "status"   = "status",
 *   },
 *   revision_metadata_keys = {
 *     "revision_user"        = "revision_user",
 *     "revision_created"     = "revision_created",
 *     "revision_log_message" = "revision_log_message",
 *   },
 *   links = {
 *     "canonical"          = "/clouds/design/store/{cloud_store_type}/{cloud_store}",
 *     "add-form"           = "/clouds/design/store/{cloud_store_type}/add",
 *     "edit-form"          = "/clouds/design/store/{cloud_store_type}/{cloud_store}/edit",
 *     "delete-form"        = "/clouds/design/store/{cloud_store_type}/{cloud_store}/delete",
 *     "version-history"    = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions",
 *     "revision"           = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/view",
 *     "revision_revert"    = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/revert",
 *     "revision_delete"    = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/delete",
 *     "translation_revert" = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/revert/{langcode}",
 *     "collection"         = "/clouds/design/store/{cloud_store_type}",
 *     "copy"               = "/clouds/design/store/{cloud_store_type}/{cloud_store}/copy",
 *     "delete-multiple-form" = "/clouds/design/store/{cloud_store_type}/delete_multiple",
 *   },
 *   bundle_entity_type = "cloud_store_type",
 *   field_ui_base_route = "entity.cloud_store_type.edit_form"
 * )
 */
class CloudStore extends RevisionableContentEntityBase implements EntityOwnerInterface, CloudStoreInterface {

  use EntityChangedTrait;

  public const TAG_CREATED_BY_UID = 'cloud_store_created_by_uid';

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'uid' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function urlRouteParameters($rel) {
    $uri_route_parameters = [];

    if ($rel === 'add-form'
      && (!empty($this->getEntityType())
        && !empty($this->getEntityType()->hasKey('bundle')))) {
      $parameter_name = !empty($this->getEntityType()->getBundleEntityType()) ?: $this->getEntityType()->getKey('bundle');
      $uri_route_parameters[$parameter_name] = $this->bundle();
    }
    else {
      // The entity ID is needed as a route parameter.
      $uri_route_parameters = [
        $this->getEntityTypeId() => $this->id(),
        $this->getEntityType()->getBundleEntityType() => $this->bundle(),
      ];
    }

    if ($rel === 'revision' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }

    if ($rel === 'revision_revert' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }
    elseif ($rel === 'revision_delete' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }

    return $uri_route_parameters;
  }

  /**
   * {@inheritdoc}
   */
  public function preSave(EntityStorageInterface $storage) {
    parent::preSave($storage);

    foreach (array_keys($this->getTranslationLanguages()) as $langcode) {
      $translation = $this->getTranslation($langcode);

      // If no owner has been set explicitly, make the anonymous user the owner.
      if (!$translation->getOwner()) {
        $translation->setOwnerId(0);
      }
    }

    // If no revision author has been set explicitly, make the
    // cloud_store owner the revision author.
    if (!$this->getRevisionUser()) {
      $this->setRevisionUserId($this->getOwnerId());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name) {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('uid')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('uid')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('uid', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('uid', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished() {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published) {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the Cloud Store.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 11,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'match_limit' => 10,
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The name of the cloud store.'))
      ->setRevisionable(TRUE)
      ->setSettings([
        'max_length' => 50,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the cloud store is published.'))
      ->setRevisionable(TRUE)
      ->setDefaultValue(TRUE)
      ->setReadOnly(TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    $fields['revision_translation_affected'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Revision translation affected'))
      ->setDescription(t('Indicates if the last edit of a translation belongs to current revision.'))
      ->setReadOnly(TRUE)
      ->setRevisionable(TRUE)
      ->setTranslatable(TRUE);

    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function delete() {
    parent::delete();
    self::updateCache();
  }

  /**
   * {@inheritdoc}
   */
  public function save() {
    $return = parent::save();
    self::updateCache();
    return $return;
  }

  /**
   * Helper method to update caches.
   *
   * Be careful using this function especially during batch processing
   * or entity imports.  Call this method only when necessary.
   */
  public static function updateCache() {
    // Clear block and menu cache.
    \Drupal::cache('menu')->invalidateAll();
    \Drupal::service('cache.render')->deleteAll();
    \Drupal::service('router.builder')->rebuild();
    \Drupal::service('plugin.cache_clearer')->clearCachedDefinitions();
  }

}

==> cloud-3.2.0.tar.gz: cloud/src/Entity/CloudStore.php <==
<?php

namespace Drupal\cloud\Entity;

use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\RevisionableInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\user\UserInterface;
use Drupal\user\Entity\User;

/**
 * Defines the cloud Store entity.
 *
 * @ingroup cloud_store
 *
 * @ContentEntityType(
 *   id = "cloud_store",
 *   id_plural = "cloud_stores",
 *   label = @Translation("Cloud Store"),
 *   label_collection = @Translation("Cloud Stores"),
 *   label_singular = @Translation("cloud store"),
 *   label_plural = @Translation("cloud stores"),
 *   bundle_label = @Translation("cloud store type"),
 *   handlers = {
 *     "storage"      = "Drupal\cloud\Entity\CloudStoreStorage",
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudStoreListBuilder",
 *     "views_data"   = "Drupal\cloud\Entity\CloudStoreViewsData",
 *     "translation"  = "Drupal\cloud\Entity\CloudStoreTranslationHandler",
 *
 *     "form" = {
 *       "default" = "Drupal\cloud\Form\CloudStoreForm",
 *       "add"     = "Drupal\cloud\Form\CloudStoreForm",
 *       "edit"    = "Drupal\cloud\Form\CloudStoreForm",
 *       "delete"  = "Drupal\cloud\Form\CloudStoreDeleteForm",
 *       "copy"    = "Drupal\cloud\Form\CloudStoreForm",
 *       "delete-multiple-confirm" = "Drupal\cloud\Form\CloudStoreDeleteMultipleForm",
 *     },
 *     "access" = "Drupal\cloud\Controller\CloudStoreAccessControlHandler",
 *     "route_provider" = {
 *       "html" = "Drupal\cloud\Routing\CloudStoreHtmlRouteProvider",
 *     },
 *   },
 *   base_table          = "cloud_store",
 *   data_table          = "cloud_store_field_data",
 *   revision_table      = "cloud_store_revision",
 *   revision_data_table = "cloud_store_field_revision",
 *   translatable        = TRUE,
 *   admin_permission    = "administer cloud stores",
 *   entity_keys = {
 *     "id" = "id",
 *     "revision" = "vid",
 *     "bundle"   = "type",
 *     "label"    = "name",
 *     "uuid"     = "uuid",
 *     "uid"      = "uid",
 *     "langcode" = "langcode",
 *     "status"   = "status",
 *   },
 *   revision_metadata_keys = {
 *     "revision_user"        = "revision_user",
 *     "revision_created"     = "revision_created",
 *     "revision_log_message" = "revision_log_message",
 *   },
 *   links = {
 *     "canonical"          = "/clouds/design/store/{cloud_store_type}/{cloud_store}",
 *     "add-form"           = "/clouds/design/store/{cloud_store_type}/add",
 *     "edit-form"          = "/clouds/design/store/{cloud_store_type}/{cloud_store}/edit",
 *     "delete-form"        = "/clouds/design/store/{cloud_store_type}/{cloud_store}/delete",
 *     "version-history"    = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions",
 *     "revision"           = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/view",
 *     "revision_revert"    = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/revert",
 *     "revision_delete"    = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/delete",
 *     "translation_revert" = "/clouds/design/store/{cloud_store_type}/{cloud_store}/revisions/{cloud_store_revision}/revert/{langcode}",
 *     "collection"         = "/clouds/design/store/{cloud_store_type}",
 *     "copy"               = "/clouds/design/store/{cloud_store_type}/{cloud_store}/copy",
 *     "delete-multiple-form" = "/clouds/design/store/{cloud_store_type}/delete_multiple",
 *   },
 *   bundle_entity_type = "cloud_store_type",
 *   field_ui_base_route = "entity.cloud_store_type.edit_form"
 * )
 */
class CloudStore extends CloudContentEntityBase implements CloudStoreInterface {

  use EntityChangedTrait;

  public const TAG_CREATED_BY_UID = 'cloud_store_created_by_uid';

  /**
   * {@inheritdoc}
   */
  protected function urlRouteParameters($rel) {
    $uri_route_parameters = [];

    if ($rel === 'add-form'
      && (!empty($this->getEntityType())
        && !empty($this->getEntityType()->hasKey('bundle')))) {
      $parameter_name = !empty($this->getEntityType()->getBundleEntityType()) ?: $this->getEntityType()->getKey('bundle');
      $uri_route_parameters[$parameter_name] = $this->bundle();
    }
    else {
      // The entity ID is needed as a route parameter.
      $uri_route_parameters = [
        $this->getEntityTypeId() => $this->id(),
        $this->getEntityType()->getBundleEntityType() => $this->bundle(),
      ];
    }

    if ($rel === 'revision' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }

    if ($rel === 'revision_revert' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }
    elseif ($rel === 'revision_delete' && $this instanceof RevisionableInterface) {
      $uri_route_parameters[$this->getEntityTypeId() . '_revision'] = $this->getRevisionId();
    }

    return $uri_route_parameters;
  }

  /**
   * {@inheritdoc}
   */
  public function preSave(EntityStorageInterface $storage): void {
    parent::preSave($storage);

    foreach (array_keys($this->getTranslationLanguages()) as $langcode) {
      $translation = $this->getTranslation($langcode);

      // If no owner has been set explicitly, make the anonymous user the owner.
      if (!$translation->getOwner()) {
        $translation->setOwnerId(0);
      }
    }

    // If no revision author has been set explicitly, make the
    // cloud_store owner the revision author.
    if (!$this->getRevisionUser()) {
      $this->setRevisionUserId($this->getOwnerId());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getName(): string {
    return $this->get('name')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setName($name): CloudStore {
    $this->set('name', $name);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime(): string {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp): CloudStore {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner(): User {
    return $this->get('uid')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId(): string {
    return $this->get('uid')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid): CloudStore {
    $this->set('uid', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account): CloudStore {
    $this->set('uid', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isPublished(): bool {
    return (bool) $this->getEntityKey('status');
  }

  /**
   * {@inheritdoc}
   */
  public function setPublished($published): CloudStore {
    $this->set('status', $published ? TRUE : FALSE);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The user ID of author of the Cloud Store.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 11,
      ])
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => [
          'match_operator' => 'CONTAINS',
          'match_limit' => 10,
          'size' => '60',
          'autocomplete_type' => 'tags',
          'placeholder' => '',
        ],
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('The name of the cloud store.'))
      ->setRevisionable(TRUE)
      ->setSettings([
        'max_length' => 255,
        'text_processing' => 0,
      ])
      ->setDefaultValue('')
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ])
      ->setDisplayOptions('form', [
        'type' => 'string_textfield',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE)
      ->setRequired(TRUE);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the cloud store is published.'))
      ->setRevisionable(TRUE)
      ->setDefaultValue(TRUE)
      ->setReadOnly(TRUE);

    $fields['cloud_context'] = BaseFieldDefinition::create('string')
      ->setLabel(t('[Unused column] Cloud Service Provider ID'))
      ->setDescription(t('[Unused column]  A unique ID for the cloud service provider.'))
      ->setRevisionable(TRUE)
      ->setReadOnly(TRUE)
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'string',
        'weight' => -4,
      ]);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was last edited.'));

    $fields['revision_translation_affected'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Revision translation affected'))
      ->setDescription(t('Indicates if the last edit of a translation belongs to current revision.'))
      ->setReadOnly(TRUE)
      ->setRevisionable(TRUE)
      ->setTranslatable(TRUE);

    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function delete(): void {
    parent::delete();
    self::updateCache();
  }

  /**
   * {@inheritdoc}
   */
  public function save(): int {
    $return = parent::save();
    self::updateCache();
    return $return;
  }

  /**
   * Helper method to update caches.
   *
   * Be careful using this function especially during batch processing
   * or entity imports.  Call this method only when necessary.
   */
  public static function updateCache(): void {
    // Clear block and menu cache.
    \Drupal::cache('menu')->invalidateAll();
    \Drupal::service('cache.render')->deleteAll();
    \Drupal::service('router.builder')->rebuild();
    \Drupal::service('plugin.cache_clearer')->clearCachedDefinitions();
  }

}
